weaviate.schema
===============

.. automodule:: weaviate.schema
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.schema.properties
--------------------------

.. toctree::
   :maxdepth: 4

   weaviate.schema.properties


weaviate.schema.validate\_schema
--------------------------------

.. automodule:: weaviate.schema.validate_schema
   :members:
   :undoc-members:
   :show-inheritance:
